@@ -1,17 +1,15 @@
 # Author: Robert J. Hijmans
-# contact: r.hijmans@gmail.com
 # Date : December 2009
 # Version 0.1
 # Licence GPL v3
 
 
-shapefile <- function(filename) {
+shapefile <- function(filename, verbose=FALSE) {
 	if (!(require(rgdal))) {
 		stop('This function requires the rgdal package; please install it')
 	}
 	fn <- basename(filename) 
 	extension(fn) <- ''
-	vec <- readOGR(dirname(filename), fn) 
-	return(vec)
+	readOGR(dirname(filename), fn, stringsAsFactors=FALSE, verbose=verbose) 
 }
 
